package com.mycompany;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;
import javax.sql.DataSource;
import java.lang.reflect.Field;
import java.rmi.RemoteException;
import java.sql.*;

public class Utils {

    private static final String DATA_SOURCE = "jdbc/__default";

    public static MyOperationsHome getMyOperationsHome() throws RemoteException {
        try {
            InitialContext context = new InitialContext();
            return (MyOperationsHome) PortableRemoteObject.narrow(context.lookup("myoperations"), MyOperationsHome.class);
        } catch (NamingException ne) {
            throw new RemoteException("Failed to get MyOperationsHome", ne);
        }
    }

    public static YourOperationsHome getYourOperationsHome() throws RemoteException {
        try {
            InitialContext context = new InitialContext();
            return (YourOperationsHome) PortableRemoteObject.narrow(context.lookup("youroperations"), YourOperationsHome.class);
        } catch (NamingException ne) {
            throw new RemoteException("Failed to get YourOperationsHome", ne);
        }
    }

    public static NewTxOperationsHome getNewTxOperationsHome() throws RemoteException {
        try {
            InitialContext context = new InitialContext();
            return (NewTxOperationsHome) PortableRemoteObject.narrow(context.lookup("newtxoperations"), NewTxOperationsHome.class);
        } catch (NamingException ne) {
            throw new RemoteException("Failed to get NewTxOperationsHome", ne);
        }
    }

    public static DataSource getDataSource() throws RemoteException {
        try {
            InitialContext context = new InitialContext();
            return (DataSource) context.lookup(DATA_SOURCE);
        } catch (NamingException ne) {
            throw new RemoteException("Failed to get data source", ne);
        }
    }

    protected static void doInsert(DataSource dataSource, String table) throws RemoteException, SQLException {
        assert dataSource != null;

        Connection connection = null;
        PreparedStatement p = null;
        try {
            connection = dataSource.getConnection();
            printConnection(connection);
            p = connection.prepareStatement("insert into "+table+" (CREATETIME) values(?)");
            p.setTimestamp(1, new Timestamp(System.currentTimeMillis()));
            p.executeUpdate();
        } finally {
            if (p != null) {
                p.close();
            }
            if (connection != null) {
                connection.close();
            }
        }
    }

    protected static void doInsert(Connection connection, String table) throws RemoteException, SQLException {
        assert connection != null;

        PreparedStatement p = null;
        try {
            printConnection(connection);
            p = connection.prepareStatement("insert into "+table+" (CREATETIME) values(?)");
            p.setTimestamp(1, new Timestamp(System.currentTimeMillis()));
            p.executeUpdate();
        } finally {
            if (p != null) {
                p.close();
            }
        }
    }

    protected static void doSelect(DataSource dataSource, String table) throws RemoteException, SQLException {
        assert dataSource != null;

        Connection connection = null;
        PreparedStatement p = null;
        try {
            connection = dataSource.getConnection();
            printConnection(connection);
            p = connection.prepareStatement("select count(*) from "+table);
            final ResultSet resultSet = p.executeQuery();
            resultSet.next();
            System.out.println("Number of rows is " + resultSet.getInt(1));
        } finally {
            if (p != null) {
                p.close();
            }
            if (connection != null) {
                connection.close();
            }
        }
    }

    private static void printConnection(Connection connection) {
        try {
            final Class clazz = Class.forName("com.sun.gjc.spi.jdbc40.ConnectionWrapper40");
            final Field field = clazz.getSuperclass().getSuperclass().getField("con");
            field.setAccessible(true);
            System.out.println("connection: "+field.get(connection));
        } catch (Exception e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
    }
}
